;; Generated package description from ibuffer-sidebar.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "ibuffer-sidebar" "1.0.0.0.20260718.2" "Sidebar for `ibuffer'" '((emacs "29.1")) :commit "d24edb3e7507f4cc8e6e3b336f49bafc2a6c3c8a" :authors '(("James Nguyen" . "james@jojojames.com")) :maintainer '("James Nguyen" . "james@jojojames.com") :keywords '("ibuffer" "files" "tools") :url "https://github.com/jojojames/ibuffer-sidebar")
